/// The different states the the GLOBAL_LOGGER can be in.
#[repr(usize)]
#[derive(Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
pub enum LoggerStates
{
   /// The GLOBAL_LOGGER has not been initialized yet.
   Uninitialized,

   /// The GLOBAL_LOGGER is currently being initialized.
   Initializing,

   /// The GLOBAL_LOGGER is initialized and ready to be used.
   Initialized
}



impl LoggerStates
{
   /// Get a str representation of this variant.
   pub fn to_str(&self) -> &'static str
   {
      match *self
      {
         LoggerStates::Uninitialized => "Uninitialized",
         LoggerStates::Initializing => "Initializing",
         LoggerStates::Initialized => "Initialized"
      }
   }

   /// Get the value of this variant.
   pub fn get_val(&self) -> usize
   {
      match *self
      {
         LoggerStates::Uninitialized => 0,
         LoggerStates::Initializing => 1,
         LoggerStates::Initialized => 2
      }
   }
}

impl ::std::convert::From<usize> for LoggerStates
{
   fn from(lvl: usize) -> LoggerStates
   {
      match lvl
      {
         0 => LoggerStates::Uninitialized,
         1 => LoggerStates::Initializing,
         2 => LoggerStates::Initialized,
         _ => LoggerStates::Uninitialized
      }
   }
}

impl ::std::convert::From<LoggerStates> for usize
{
   fn from(state: LoggerStates) -> usize
   {
      state.get_val()
   }
}

impl ::std::fmt::Debug for LoggerStates
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}

impl ::std::fmt::Display for LoggerStates
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}
